@@ -7,8 +7,9 @@ class LoadingTestCase(unittest.TestCase):
         self.assertRaises(OSError, load_dll, 'geosh_c')
     def test_fallbacks(self):
         a = load_dll('geosh_c', fallbacks=[
-            '/opt/local/lib/libgeos_c.dylib',
-            'libgeos_c.so.1', 
+            '/opt/local/lib/libgeos_c.dylib', # MacPorts
+            '/usr/local/lib/libgeos_c.dylib', # homebrew (Mac OS X)
+            'libgeos_c.so.1',
             'libgeos_c.so'])
 
 def test_suite():
